.. py:function:: sf_gegenpoly_2_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_gegenpoly_2_e`
    c code signature: int gsl_sf_gegenpoly_2_e( double lambda,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_gegenpoly_1(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_gegenpoly_1`
    c code signature: double gsl_sf_gegenpoly_1( double lambda,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_gegenpoly_2(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_gegenpoly_2`
    c code signature: double gsl_sf_gegenpoly_2( double lambda,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_gegenpoly_1_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_gegenpoly_1_e`
    c code signature: int gsl_sf_gegenpoly_1_e( double lambda,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_gegenpoly_n_e(n, lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_gegenpoly_n_e`
    c code signature: int gsl_sf_gegenpoly_n_e( int n,  double lambda,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rl__Ord`
    
    :param int n: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param int ret: positional argument 3
    :param double result.val: positional argument 4
    :param double result.err: positional argument 5
    :rtype:  tuple(:param int ret: positional argument 3, :param double result.val: positional argument 4, :param double result.err: positional argument 5) 
    :return: result 

.. py:function:: sf_gegenpoly_3_e(lambda, x [, ret, result.val, result.err])

    Wrapper for :c:func:`gsl_sf_gegenpoly_3_e`
    c code signature: int gsl_sf_gegenpoly_3_e( double lambda,  double x, gsl_sf_result* result)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rl__Ord`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param int ret: positional argument 2
    :param double result.val: positional argument 3
    :param double result.err: positional argument 4
    :rtype:  tuple(:param int ret: positional argument 2, :param double result.val: positional argument 3, :param double result.err: positional argument 4) 
    :return: result 

.. py:function:: sf_gegenpoly_3(lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_gegenpoly_3`
    c code signature: double gsl_sf_gegenpoly_3( double lambda,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double lambda: positional argument 0
    :param double x: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: sf_gegenpoly_n(n, lambda, x [, ret])

    Wrapper for :c:func:`gsl_sf_gegenpoly_n`
    c code signature: double gsl_sf_gegenpoly_n( int n,  double lambda,  double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Il_d_d__Rd__O`
    
    :param int n: positional argument 0
    :param double lambda: positional argument 1
    :param double x: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

